# Generated by Django 2.2 on 2019-07-09 16:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('anss', '0002_auto_20190709_0830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feed',
            name='api',
            field=models.CharField(blank=True, max_length=5000, verbose_name='API version'),
        ),
        migrations.AlterField(
            model_name='feed',
            name='content',
            field=models.FileField(upload_to='', verbose_name='archived GeoJSON'),
        ),
        migrations.AlterField(
            model_name='feed',
            name='count',
            field=models.IntegerField(null=True, verbose_name='earthquake count'),
        ),
        migrations.AlterField(
            model_name='feed',
            name='generated',
            field=models.BigIntegerField(null=True, verbose_name='time generated (UNIX)'),
        ),
        migrations.AlterField(
            model_name='feed',
            name='status',
            field=models.IntegerField(null=True, verbose_name='response status'),
        ),
        migrations.AlterField(
            model_name='feed',
            name='url',
            field=models.CharField(blank=True, max_length=5000, verbose_name='GeoJSON URL'),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='detail',
            field=models.CharField(blank=True, max_length=5000, verbose_name='GeoJSON'),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='time',
            field=models.BigIntegerField(null=True, verbose_name='UNIX time'),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='url',
            field=models.CharField(blank=True, max_length=5000, verbose_name='Summary page'),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='usgs_id',
            field=models.CharField(blank=True, max_length=5000, verbose_name='USGS ID'),
        ),
    ]



# Generated by Django 2.2 on 2019-07-09 18:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('anss', '0005_auto_20190709_1035'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feedearthquake',
            name='status',
            field=models.CharField(blank=True, help_text='Indicates whether the event has been reviewed by a human. Status is either automatic or reviewed. Automatic events are directly posted by automatic processing systems and have not been verified or altered by a human. Reviewed events have been looked at by a human. The level of review can range from a quick validity check to a careful reanalysis of the event.', max_length=5000),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='title',
            field=models.CharField(blank=True, help_text='A summary of the event', max_length=5000, verbose_name='description'),
        ),
    ]
